import email
from setuptools import setup

setup(
    name='primosa02',
    version='0.0.1',
    description='Calculate prime numbers',
)

setup(classifiers=["Programming Language :: Python :: 3 :: Only",
"License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",
"Operating System :: OS Independent",],)

setup(install_requires=["rpy2",],)

setup(url="https://github.com/OscarVC2/primos",
author="Oscar Valladares",
author_email="oscarvc.2@gmail.com",)


import rpy2.robjects as ro
from rpy2.robjects import r

def primosOAVC2(n):
  r.assign("n", n)
  r('''
  if (n >= 1) {
  x = seq(1, n)
  for (i in seq(2, n)) {
  if (any(x == i)) {
  print(i)
  x = c(x[(x %% i) != 0], i)
  }
  }
  }
  ''')